pub fn get_round_constants_t2(env: &Env) -> Vec<Vec<U256>>Expand description
Poseidon2 round constants for BN256 field These are the constants used in the Poseidon2 permutation for T=2
pub fn get_round_constants_t2(env: &Env) -> Vec<Vec<U256>>Poseidon2 round constants for BN256 field These are the constants used in the Poseidon2 permutation for T=2