pub fn get_zeroes(env: &Env) -> Vec<U256>Expand description
Get the zero hash values for each level of a Merkle tree
Hash of 0 at the leaf level is defined as Poseidon2 hash of “XLM” encoded as ASCII. More specifically, t=4, r=3, domain_sep=0. poseidon2(88, 76,77) = poseidon2(“XLM”). From there, we use the poseidon2 compression function to get the zero hash for each level.