pub struct MockTokenClient<'a> {
pub env: Env,
pub address: Address,
/* private fields */
}Expand description
MockTokenClient is a client for calling the contract defined in “MockToken”.
Fields
env: Envaddress: AddressImplementations
Sourceimpl<'a> MockTokenClient<'a>
impl<'a> MockTokenClient<'a>
pub fn new(env: &Env, address: &Address) -> Self
Sourcepub fn set_auths(&self, auths: &'a [SorobanAuthorizationEntry]) -> Self
pub fn set_auths(&self, auths: &'a [SorobanAuthorizationEntry]) -> Self
Set authorizations in the environment which will be consumed by
contracts when they invoke Address::require_auth or
Address::require_auth_for_args functions.
Requires valid signatures for the authorization to be successful.
To mock auth without requiring valid signatures, use mock_auths.
See soroban_sdk::Env::set_auths for more details and examples.
Sourcepub fn mock_auths(&self, mock_auths: &'a [MockAuth<'a>]) -> Self
pub fn mock_auths(&self, mock_auths: &'a [MockAuth<'a>]) -> Self
Mock authorizations in the environment which will cause matching invokes
of Address::require_auth and Address::require_auth_for_args to
pass.
See soroban_sdk::Env::set_auths for more details and examples.
Sourcepub fn mock_all_auths(&self) -> Self
pub fn mock_all_auths(&self) -> Self
Mock all calls to the Address::require_auth and
Address::require_auth_for_args functions in invoked contracts,
having them succeed as if authorization was provided.
See soroban_sdk::Env::mock_all_auths for more details and
examples.
Sourcepub fn mock_all_auths_allowing_non_root_auth(&self) -> Self
pub fn mock_all_auths_allowing_non_root_auth(&self) -> Self
A version of mock_all_auths that allows authorizations that
are not present in the root invocation.
Refer to mock_all_auths documentation for details and
prefer using mock_all_auths unless non-root authorization is
required.
See soroban_sdk::Env::mock_all_auths_allowing_non_root_auth
for more details and examples.
Sourceimpl<'a> MockTokenClient<'a>
impl<'a> MockTokenClient<'a>
pub fn balance(&self, _id: &Address) -> i128
pub fn try_balance( &self, _id: &Address, ) -> Result<Result<i128, <i128 as TryFromVal<Env, Val>>::Error>, Result<Error, InvokeError>>
pub fn transfer(&self, _from: &Address, _to: &Address, _amount: &i128)
pub fn try_transfer( &self, _from: &Address, _to: &Address, _amount: &i128, ) -> Result<Result<(), <() as TryFromVal<Env, Val>>::Error>, Result<Error, InvokeError>>
pub fn transfer_from(&self, _from: &Address, _to: &Address, _amount: &i128)
pub fn try_transfer_from( &self, _from: &Address, _to: &Address, _amount: &i128, ) -> Result<Result<(), <() as TryFromVal<Env, Val>>::Error>, Result<Error, InvokeError>>
pub fn approve(&self, _from: &Address, _spender: &Address, _amount: &i128)
pub fn try_approve( &self, _from: &Address, _spender: &Address, _amount: &i128, ) -> Result<Result<(), <() as TryFromVal<Env, Val>>::Error>, Result<Error, InvokeError>>
pub fn allowance(&self, _from: &Address, _spender: &Address) -> i128
pub fn try_allowance( &self, _from: &Address, _spender: &Address, ) -> Result<Result<i128, <i128 as TryFromVal<Env, Val>>::Error>, Result<Error, InvokeError>>